
class GlideParams(object):


    def generate_glide_params(self, args):
        self.precision_glide = args.precision_glide
